@@ -10,6 +10,9 @@ $libDir = "/usr/local/lib/xisofs";
 # Where the main binary is sym-linked to
 $binDir = "/usr/local/bin";
 
+# Where the perl executable is, leave blank for PATH
+$perlPath = "";
+
 #----------------------------------------------------------------------
 # Nothing below here should need changing
 #----------------------------------------------------------------------
@@ -22,17 +25,50 @@ if ($who ne 'root')
 	exit 1;
 }
 
+if ($perlPath eq '')
+{
+	chomp($perlPath = `which perl`);
+	unless (-e $perlPath)
+	{
+		print "Cannot find perl executable on PATH, either set PATH to point to perl\nexecutable, or edit this script and alter the \$perlPath variable\n";
+		exit 1;
+	}
+}
+
 print <<EOT;
 
-xisofs v1.2 Installation Script
+xisofs v1.3 Installation Script
 (c) Copyright 1997 Steve Sherwood
 
-Library Dir    : $libDir
-Executable Dir : $binDir
-
+Library Dir      : $libDir
+Executable Dir   : $binDir
+Perl Executable  : $perlPath
 EOT
 
-print "Are you sure you wish to install (y/n) ? ";
+if (-d $libDir)
+{
+	if (-r "$libDir/VERSION")
+	{
+		open(IN,"$libDir/VERSION");
+		$_ = <IN>;
+		close(IN);
+
+		if (/^xisofs/)
+		{
+			print "Previous Version : $_\n";
+		}
+		else
+		{
+			print "\nWARNING : $libDir exists, but does not contain a\n          recognised version of xisofs\n";
+		}
+	}
+	else
+	{
+		print "\nWARNING : $libDir exists, but does not contain a\n          recognised version of xisofs\n"
+	}
+}
+
+print "\nAre you sure you wish to install (y/n) ? ";
 $_ = <STDIN>;
 
 unless (/^y/)
@@ -64,6 +100,7 @@ seek(IO,0,0);
 foreach(@lines)
 {
 	s/xyzzy/$libDir/g;
+	s/yyzzy/$perlPath/g;
 	print IO $_;
 }
 close(IO);
